pub struct Config {
pub serializer: Serializer,
pub runtime: Runtime,
pub num_workers: Option<usize>,
pub amqp_uri: Option<String>,
pub task_bus_routing_key: Option<String>,
}Expand description
Represents the main configuration structure for the runtime.
Fields
serializer: SerializerDetermines the serialization format to be used.
runtime: RuntimeSpecifies the runtime environment to use.
num_workers: Option<usize>Specifies the number of worker threads to spawn (in memory runtime only).
amqp_uri: Option<String>Provides the URI for the AMQP broker, if the AMQP runtime is selected.
task_bus_routing_key: Option<String>Provides the routing key for workers to listen on, if the AMQP runtime is used in configuration.