Module queue

Module queue 

Simplified interface for interacting with queues.

Different queuing systems will provide many different configuration options and features — we do not attempt to provide a unified interface for all of them. Rather, we provided a bare minimum interface that is sufficient to satisfy the semantics of this system. In particular, connection management, queue declaration, queue consumption, and message publishing are the only operations that are supported.

Modules

amqp
AMQP queue binding using lapin.
in_memory
An in-memory implementation of Connection and its associated types.

Structs

QueueOptions
Queue declaration options.
With
Publisher for the PublisherExt::with function.

Enums

DeliveryMode
The delivery mode of a message.
QueueDurability
The durability of a queue.
SyndicationMode
The syndication mode of a queue.

Traits

Connection
A connection to a queue.
Publisher
A non-locking replacement for Sink.
PublisherExt
Extension trait for Publisher.
QueueHandle
A handle to a queue.