pub struct AMQPConnectionOptions<'a> {
pub uri: &'a str,
pub qos: Option<u16>,
pub serializer: Serializer,
}Expand description
Options for creating an AMQPConnection.
Fields
uri: &'a strThe AMQP URI to connect to.
qos: Option<u16>The Quality of Service to use for the queue. This determines how many unacknowledged messages the broker will deliver to the consumer before requiring acknowledgements. By setting this, you can control the rate at which messages are delivered to a consumer, thus affecting throughput and ensuring that a single consumer doesn’t get overwhelmed. See https://www.rabbitmq.com/consumer-prefetch.html
serializer: SerializerAuto Trait Implementations
impl<'a> Freeze for AMQPConnectionOptions<'a>
impl<'a> RefUnwindSafe for AMQPConnectionOptions<'a>
impl<'a> Send for AMQPConnectionOptions<'a>
impl<'a> Sync for AMQPConnectionOptions<'a>
impl<'a> Unpin for AMQPConnectionOptions<'a>
impl<'a> UnwindSafe for AMQPConnectionOptions<'a>