pub enum SyndicationMode {
ExactlyOnce,
Broadcast,
}Expand description
The syndication mode of a queue.
Variants
ExactlyOnce
A single-delivery queue will deliver a message to a single consumer.
Broadcast
A broadcast queue will deliver a message to all consumers.