Module in_memory

Module in_memory 

An in-memory implementation of Connection and its associated types.

This implementation is useful for testing and debugging purposes, as it provides a simple, in-memory queue that can be used to emulate a real queue. It uses asynchronous synchronization primitives to faithfully emulate the behavior of a real queue, and is well suited for a multi-threaded and/or asynchronous environment.

The InMemoryConnection is cloneable can be used to simulate a connection pool to a real queue. Each clone of the connection will maintain references to same underlying queues.

Structs

InMemoryConnection
An in-memory implementation of Connection.
InMemoryConsumer
A Stream implementation for InMemoryConsumer.
InMemoryPublisher
InMemoryQueueHandle
An in-memory implementation of QueueHandle.